@@ -19,7 +19,7 @@ define([
      * html load 콜백. 고유 id 생성하여 부과하며 js 객체 클래스 생성하여 컨테이너로 전달
      * @param {function} callback 호출자(컨테이너) 의 콜백함수
      */
-    var optionLoadCallback = function(callback) {
+    var optionLoadCallback = function(callback, meta) {
         // document.getElementsByTagName("head")[0].appendChild(link);
         // 컨테이너에서 전달된 callback 함수가 존재하면 실행.
         if (typeof(callback) === 'function') {
@@ -31,10 +31,11 @@ define([
                     uuid = vpCommon.getUUID();
                 }
             }
-            $(vpCommon.wrapSelector(vpConst.OPTION_GREEN_ROOM)).find(vpConst.OPTION_PAGE).addClass(uuid);
+            $(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.OPTION_GREEN_ROOM))).find(vpCommon.formatString(".{0}", vpConst.API_OPTION_PAGE)).addClass(uuid);
 
             // 옵션 객체 생성
             var mpPackage = new MatplotPackage(uuid);
+            mpPackage.metadata = meta;
 
             // 옵션 속성 할당.
             mpPackage.setOptionProp(funcOptProp);
@@ -48,8 +49,8 @@ define([
      * html 로드. 
      * @param {function} callback 호출자(컨테이너) 의 콜백함수
      */
-    var initOption = function(callback) {
-        vpCommon.loadHtml(vpCommon.wrapSelector(vpConst.OPTION_GREEN_ROOM), "matplotlib/plot.html", optionLoadCallback, callback);
+    var initOption = function(callback, meta) {
+        vpCommon.loadHtml(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.OPTION_GREEN_ROOM)), "matplotlib/plot.html", optionLoadCallback, callback, meta);
     }
 
     /**
@@ -305,7 +306,7 @@ define([
             },
             'pie': {
                 code: '${i0}.${kind}(${x}${v}${etc})',
-                tailCode: `${i0}.axis('equal')`,
+                tailCode: "${i0}.axis('equal')",
                 input: [
                     {
                         name: 'i0',
@@ -329,6 +330,7 @@ define([
             },
             'hexbin': {
                 code: '${i0}.${kind}(${x}, ${y}${v}${etc})',
+                tailCode: '${i0}.colorbar()', // 색상 막대 범례 표시
                 input: [
                     {
                         name: 'i0',
@@ -366,7 +368,6 @@ define([
             },
             'contour': {
                 code: '${i0}.${kind}(${x}, ${y}, ${z}${v}${etc})',
-                tailCode: '${i0}.colorbar()', // 색상 막대 범례 표시
                 input: [
                     {
                         name: 'i0',
@@ -771,14 +772,25 @@ define([
             selector.append(option);
         });
 
+        // 기존 유형 선택하는 select 태그 안보이게
+        $(selector).hide();
+
         // 차트유형 선택지에 맞게 옵션 표시
-        $(selector).change(function() {
-            var kind = $(this).val();
+        // $(selector).change(function() {
+        $(this.wrapSelector('#vp_plotKind .vp-plot-item')).click(function() {
+            // 선택한 플롯 유형 박스 표시
+            $(this).parent().find('.vp-plot-item').removeClass('selected');
+            $(this).addClass('selected');
+
+            // select 태그 강제 선택
+            var kind = $(this).data('kind');
+            $(selector).val(kind).prop('selected', true);
+
             var package = that.plotPackage[kind];
             if (package == undefined) package = that.plotPackage['plot'];
 
             // 모두 숨기기 (단, 대상 변수 입력란과 차트 유형 선택지 제외)
-            $(that.wrapSelector('#vp_plotSetting table tr:gt(2)')).hide();
+            $(that.wrapSelector('#vp_plotSetting table tr:gt(1)')).hide();
 
             // 해당 옵션에 있는 선택지만 보이게 처리
             package.input.forEach(obj => {
@@ -792,7 +804,7 @@ define([
         // 플롯 차트 옵션으로 초기화
         var plotPackage = this.plotPackage['plot'];
         // 모두 숨기기 (단, 대상 변수 입력란과 차트 유형 선택지 제외)
-        $(this.wrapSelector('#vp_plotSetting table tr:gt(2)')).hide();
+        $(this.wrapSelector('#vp_plotSetting table tr:gt(1)')).hide();
 
         // 해당 옵션에 있는 선택지만 보이게 처리
         plotPackage.input.forEach(obj => {
@@ -898,7 +910,7 @@ define([
      * 코드 생성
      * @param {boolean} exec 실행여부
      */
-    MatplotPackage.prototype.generateCode = function(exec) {
+    MatplotPackage.prototype.generateCode = function(addCell, exec) {
         if (!this.optionValidation()) return;
 
         try {
@@ -1022,7 +1034,7 @@ define([
 
             // 코드 추가 및 실행
             if (doGenerate) {
-                this.cellExecute(sbCode.toString(), exec);
+                if (addCell) this.cellExecute(sbCode.toString(), exec);
             } else {
                 throw '생성할 코드가 없습니다.';
             }
@@ -1031,6 +1043,8 @@ define([
             vpCommon.renderAlertModal(exmsg);
             return "BREAK_RUN"; // 코드 생성 중 오류 발생
         }
+
+        return sbCode.toString();
     }
 
     return {
