@@ -20,7 +20,7 @@ define([
      * html load 콜백. 고유 id 생성하여 부과하며 js 객체 클래스 생성하여 컨테이너로 전달
      * @param {function} callback 호출자(컨테이너) 의 콜백함수
      */
-    var optionLoadCallback = function(callback) {
+    var optionLoadCallback = function(callback, meta) {
         // document.getElementsByTagName("head")[0].appendChild(link);
         // 컨테이너에서 전달된 callback 함수가 존재하면 실행.
         if (typeof(callback) === 'function') {
@@ -32,10 +32,11 @@ define([
                     uuid = vpCommon.getUUID();
                 }
             }
-            $(vpCommon.wrapSelector(vpConst.OPTION_GREEN_ROOM)).find(vpConst.OPTION_PAGE).addClass(uuid);
+            $(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.OPTION_GREEN_ROOM))).find(vpCommon.formatString(".{0}", vpConst.API_OPTION_PAGE)).addClass(uuid);
 
             // 옵션 객체 생성
             var pdPackage = new PandasPackage(uuid);
+            pdPackage.metadata = meta;
 
             // 옵션 속성 할당.
             pdPackage.setOptionProp(funcOptProp);
@@ -49,8 +50,8 @@ define([
      * html 로드. 
      * @param {function} callback 호출자(컨테이너) 의 콜백함수
      */
-    var initOption = function(callback) {
-        vpCommon.loadHtml(vpCommon.wrapSelector(vpConst.OPTION_GREEN_ROOM), "pandas/plot.html", optionLoadCallback, callback);
+    var initOption = function(callback, meta) {
+        vpCommon.loadHtml(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.OPTION_GREEN_ROOM)), "pandas/plot.html", optionLoadCallback, callback, meta);
     }
 
     /**
@@ -324,7 +325,7 @@ define([
      * 코드 생성
      * @param {boolean} exec 실행여부
      */
-    PandasPackage.prototype.generateCode = function(exec) {
+    PandasPackage.prototype.generateCode = function(addCell, exec) {
         if (!this.optionValidation()) return;
         
         try {
@@ -362,12 +363,14 @@ define([
                 sbCode.append(postfix);
             }
 
-            this.cellExecute(sbCode.toString(), exec);
+            if (addCell) this.cellExecute(sbCode.toString(), exec);
         } catch (exmsg) {
             // 에러 표시
             vpCommon.renderAlertModal(exmsg);
             return "BREAK_RUN";
         }
+
+        return sbCode.toString();
     }
 
     return {
